DimensionOrder

Enum DimensionOrder 

pub enum DimensionOrder {
    CXY,
    CYX,
    XCY,
    XYC,
    YCX,
    YXC,
}
Specify the dimension order of an image array.

For example, if dimension_order is “XYC”, then the data array must be in (X, Y, C) order, and the shape would be [img_w, img_h, num_channels]. For 2D images, the parent can simply specify dimension_order = “CXY” with num_channels of 1, as the contiguous data array will be the same regardless of whether the order is CXY vs XY. For 4D and 5D images with T and Z dimensions, the parent layer is expected to slice the data into 3D XY(C) slices for the specified z_index and t_index before passing onward. Similarly, if the original data array contains more channels than being visualized, the parent layer is responsible to slice them and provide them in the order that corresponds with the provided channel_settings c_index values.

Variants



CXY



CYX



XCY



XYC



YCX



YXC

Implementations

Source

impl DimensionOrder

pub fn as_str(&self) -> &'static str

Returns the string representation of the dimension order (e.g., “CYX”).

pub fn num_dims(&self) -> usize

Returns the number of dimensions.

pub fn channel_dim_index(&self) -> usize

Returns the position of the channel dimension in the shape array, if present.