pub struct OmeZarrBitmapMultiscaleLayerParams {
pub layer_id: String,
pub bounds: Option<MarginParams>,
pub store_name: Option<String>,
pub group_path: Option<String>,
pub multiscale_index: Option<usize>,
pub target_z: Option<u32>,
pub target_t: Option<u32>,
pub channel_settings: Vec<OmeZarrChannelSetting>,
pub opacity: f32,
}Expand description
Layer params struct for OmeZarrBitmapMultiscaleLayer.
Fields
layer_id: Stringbounds: Option<MarginParams>store_name: Option<String>Name of the top-level store to read from (a key in RenderParams::stores).
May be omitted when exactly one top-level store is defined.
group_path: Option<String>Path to the zarr group containing the multiscale metadata. Defaults to “/”.
multiscale_index: Option<usize>Which multiscale entry to use (index into the multiscales array). Defaults to 0.
target_z: Option<u32>Z slice index. Defaults to 0.
target_t: Option<u32>T slice index. Defaults to 0.
channel_settings: Vec<OmeZarrChannelSetting>Channel settings specifying which channels to render and how.
opacity: f32Trait Implementations
Sourceimpl Clone for OmeZarrBitmapMultiscaleLayerParams
impl Clone for OmeZarrBitmapMultiscaleLayerParams
Sourcefn clone(&self) -> OmeZarrBitmapMultiscaleLayerParams
fn clone(&self) -> OmeZarrBitmapMultiscaleLayerParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for OmeZarrBitmapMultiscaleLayerParams
impl Default for OmeZarrBitmapMultiscaleLayerParams
Sourcefn default() -> OmeZarrBitmapMultiscaleLayerParams
fn default() -> OmeZarrBitmapMultiscaleLayerParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OmeZarrBitmapMultiscaleLayerParams
impl<'de> Deserialize<'de> for OmeZarrBitmapMultiscaleLayerParams
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<OmeZarrBitmapMultiscaleLayerParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<OmeZarrBitmapMultiscaleLayerParams, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for OmeZarrBitmapMultiscaleLayerParams
impl Serialize for OmeZarrBitmapMultiscaleLayerParams
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more