pub struct ViewParams {Show 13 fields
pub view_id: String,
pub width: u32,
pub height: u32,
pub aspect_ratio_mode: AspectRatioMode,
pub aspect_ratio_alignment_mode: AspectRatioAlignmentMode,
pub device_pixel_ratio: f32,
pub camera_view: Option<[f32; 16]>,
pub timeout: Option<u32>,
pub wait_for_store_gets: bool,
pub cache_enabled: bool,
pub margins: Option<MarginParams>,
pub stores: Option<HashMap<String, ZarrStoreInfo>>,
pub store_objects: Option<StoreMap>,
}Expand description
Shared rendering parameters at the view level (i.e., not layer-specific).
Fields
view_id: StringThe view ID.
width: u32height: u32aspect_ratio_mode: AspectRatioModeaspect_ratio_alignment_mode: AspectRatioAlignmentModedevice_pixel_ratio: f32camera_view: Option<[f32; 16]>The camera state, as a 4x4 matrix.
timeout: Option<u32>Timeout (in ms) before bailing out of awaiting a data request.
wait_for_store_gets: boolIf false, bail early (e.g., upon encountering a pending Promise) rather than waiting for data requests to resolve.
cache_enabled: boolAllow disabling memoization/cacheing.
margins: Option<MarginParams>Specify margins for plots that need them (e.g. scatterplot axes).
Subtract margins from view-level width/height to obtain layer-level width/height.
stores: Option<HashMap<String, ZarrStoreInfo>>Mapping from zarr store name to its metadata.
Keeping track of store metadata in parallel with the store instances in
[store_objects] enables serializing store info,
facilitating the render-to-script functionality.
store_objects: Option<StoreMap>Mapping from zarr store name to its zarrs store instance.
Not serialized.
Implementations
Sourceimpl ViewParams
impl ViewParams
Sourcepub fn get_store(&self, store_name: &str) -> Arc<dyn AsyncReadableStorageTraits> ⓘ
pub fn get_store(&self, store_name: &str) -> Arc<dyn AsyncReadableStorageTraits> ⓘ
Given a Zarr store name, obtain the corresponding store instance from the ViewParams::store_objects hashmap.